==> nextcloud-23.0.8.tgz: nextcloud/apps/circles/l10n/vi.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Vòng kết nối",
    "Circles' files" : "Các tệp tin của các vòng kết nối",
    "Select circles to filter by" : "Chọn các vòng kết nối để lọc bởi",
    "No circles found" : "Không có vòng kết nối được tìm thấy",
    "Please select circles to filter by" : "Vui lòng chọn các vòng kết nới để lọc bởi",
    "No files found for the selected circles" : "Không có tệp được tìm thấy cho vòng kết nối được chọn",
    "You created the circle {circle}" : "Bạn đã tạo một vòng kết nối {circle}",
    "{author} created the circle {circle}" : "{author} đã tạo một vòng kết nối {circle}",
    "You deleted {circle}" : "Bạn đã xóa {circle}",
    "{author} deleted {circle}" : "{author} đã xóa {circle}",
    "You linked {group} to {circle}" : "Bạn đã liên kết {group} đến {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} vừa mới được liên kết đến {circle } bởi {author}",
    "You unlinked {group} from {circle}" : " Bạn đã hủy liên kết {group} từ {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} vừa mới được hủy liên kết từ {circle} bởi {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Bạn đã thay đổi cấp độ của nhóm được liên kết {group} trong {circle} ở mức %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} đã thay đổi cấp độ của nhóm được liên kết {group} trong {circle} ở mức %1$s",
    "You sent a request to link {circle} with {remote}" : "Bạn đã gửi 1 yêu cầu để liên kết {circle} với {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} gửi một yêu cầu để liên kết {circle} với {remote}",
    "{remote} requested a link with {circle}" : "{remote} đã yêu cầu một liên kết với {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Các yêu cầu để liên kết {circle} với {remote} đã bị từ chối",
    "The request to link {remote} with {circle} has been canceled remotely" : "Yêu cầu để liên kết {remote} với {circle} đã bị hủy bỏ từ xa",
    "The request to link {circle} with {remote} has been accepted" : "Yêu cầu để liên kết {circle} với {remote} đã được chấp thuận",
    "You dismissed the request to link {remote} with {circle}" : "Bạn đã bỏ qua yêu cầu liên kết {remote} với {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} đã bỏ qua yêu cầu liên kết {remote} với {circle}",
    "You canceled the request to link {circle} with {remote}" : "Bạn đã hủy yêu cầu liên kết {circle} với {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} đã hủy yêu cầu liên kết {circle} với {remote}",
    "You accepted the request to link {remote} with {circle}" : "Bạn đã chấp thuận yêu cầu liên kết {remote} với {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} đã chấp thuận yêu cầu liên kết {remote} với {circle}",
    "A link between {circle} and {remote} is now up and running" : "Một liên kết giữa {circle} và {remote} bây giờ đã khả dụng và đang chạy",
    "The link between {circle} and {remote} has been shutdown remotely" : "Một liên kết giữa {circle} và {remote} đã được tắt từ xa",
    "You closed the link between {circle} and {remote}" : "Bạn đã đóng liên kết giữ {circle} và {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} đã đóng liên kết giữa {circle} và {remote}",
    "You joined {circle}" : "Bạn đã gia nhập {circle}",
    "{member} joined {circle}" : "{nember} đã gia nhập {circle}",
    "You accepted the invitation to join {circle}" : "Bạn đã chấp thuận lời mời để gia nhập {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} đã chấp thuận lời mời để gia nhập {circle}",
    "You added {member} as member to {circle}" : "Bạn đã thêm {member} với tư cách là thành viên của {circle}",
    "You have been added as member to {circle} by {author}" : "Bạn đã được thêm vào nhóm {circle} với tư cách là thành viên bởi {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} đã được thêm với tư cách là thành viên vào {circle} bởi {author}",
    "You added {external} to {circle}" : "Bạn đã thêm {external} vào {circle}",
    "{external} has been added to {circle} by {author}" : "{externa} vừa mới được thêm vào {circle} bởi {author}",
    "You accepted {member}'s request to join {circle}" : "Bạn đã chấp thuận yêu cầu liên kết của {member} để gia nhập {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Yêu cầu gia nhập {circle} của bạn đã được chấp thuận bởi {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Yêu cầu gia nhập của {member} vào {circle} vừa mới được chấp thuận bởi {author}",
    "You left {circle}" : "Bạn đã rời bỏ {circle}",
    "{member} left {circle}" : "{member} đã rời bỏ {circle}",
    "You declined the invitation to join {circle}" : "Bạn đã từ chối lời mời gia nhập vào {circle}",
    "{member} declined an invitation to join {circle}" : "{member} đã từ chối một lời mời gia nhập vào {circle}",
    "You cancelled your request to join {circle}" : "Bạn đã hủy bỏ yêu cầu của bạn để gia nhập {circle}",
    "{member} cancelled his request to join {circle}" : "{member} đã hủy bỏ yêu cầu của anh/chị ấy để gia nhập vào {circle}",
    "You removed {member} from {circle}" : "Bạn đã gỡ bỏ {member} ra khỏi {circle}",
    "You have been removed from {circle} by {author}" : "Bạn vừa mới bị gỡ bỏ khỏi {circle} bởi {author}",
    "{member} has been removed from {circle} by {author}" : "{member} vừa mới bị gỡ bỏ khỏi {circle} bởi {author}",
    "You removed {external} from {circle}" : "Bạn gỡ bỏ {external} khỏi {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} vừa mới được gỡ bỏ khỏi {circle} bởi {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Bạn đã hủy lời mời gia nhập vào {circle} của thành viên {member}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Lời mời gia nhập vào {circle} của bạn đã bị hủy bỏ bởi {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} đã hủy bỏ lời mời tham gia vào nhóm {circle} của {member} ",
    "You dismissed {member}'s request to join {circle}" : "Bạn đã bỏ qua yêu cầu gia nhập vào {circle} của {member}",
    "Your request to join {circle} has been dismissed by {author}" : "Yêu cầu gia nhập vào {circle} của bạn đã bị bỏ qua bởi {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Yêu cầu gia nhập vào {circle} của {member} đã bị bỏ qua bởi {author}",
    "You invited {member} to join {circle}" : "Bạn đã mời {member} để gia nhập vào {circle}",
    "You have been invited to join {circle} by {author}" : "Bạn vừa mới được mời để gia nhập vào {circle} bởi {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} vừa mới được mời để gia nhập vào {circle} bởi {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Bạn đã thay đổi cấp độ của {member} trong {circle} ở mức %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} đã thay đổi cấp độ của bạn trong {circle} ở mức %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} đã thay đổi cấp độ của {member} trong {circle} ở mức %1$s",
    "You sent a request to join {circle}" : "Bạn đã gửi một yêu cầu để gia nhập {circle}",
    "{member} sent a request to join {circle}" : "{member} đã gửi một yêu cầu để gia nhập {circle}",
    "You are the new owner of {circle}" : "Bạn là chủ nhân mới của {circle}",
    "{member} is the new owner of {circle}" : "{member} là chủ nhân mới của {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Trên những sự kiên đang diễn ra trong một <strong> Vòng kết nối </strong> mà bạn là thành viên của nhóm",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Một sự kiện quan trọng trong một <strong> Vòng kết nối </strong> mà bạn đang điều hành",
    "On global events happening in any <strong>Circle</strong>" : "Trên những sự kiện chung đang diễn ra của tổ chức trong bất cứ <strong> Vòng kết nối </strong>",
    "Personal" : "Cá nhân",
    "Open" : "Mở",
    "Hidden" : "Ẩn",
    "Federated" : "Federated",
    "Contact" : "Liên hệ",
    "Circle" : "Vòng kết nối",
    "Member" : "Thành viên",
    "Moderator" : "Kiểm duyệt",
    "Admin" : "Quản trị",
    "Owner" : "Chủ",
    "%s shared »%s« with you." : "%s đã chia sẻ »%s« với bạn",
    "%s on %s" : "%s trên %s",
    "Password to access »%1$s« shared to you by %2$s" : "Mật khẩu để truy cập »%1$s« đã được chia sẻ tới bạn bởi %2$s",
    "Password to access »%s«" : "Mật khẩu để truy cập »%s«",
    "It is protected with the following password:" : "Nó được bảo vệ bởi mật khẩu sau đây:",
    "%1$s via %2$s" : "%1$s thông qua %2$s",
    "Click the button below to open it." : "Bấm vào nút bên dưới để mở nó.",
    "Open »%s«" : "Mở »%s«",
    "Password to access files shared to you by %1$s" : "Mật khẩu để truy cập vào các tệp đã được chia sẻ tới bạn bởi %1$s",
    "Password to access files" : "Mật khẩu để truy cập các tệp",
    "%s shared multiple files with you." : "%s đã chia sẻ tổ hợp tệp với bạn.",
    "Circle not found" : "Vòng kết nối không được tìm thấy",
    "Circle not found " : "Vòng kết nối không được tìm thấy",
    "A circle with that name exists" : "Đã tồn tại một vòng kết nối có tên đó",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Bạn không thể sử dụng Ứng dụng Vòng kết nối cho đến khi quản trị viên của bạn cho phép ít nhất một loại của vòng kết nối",
    "This member does not exist" : "Thành viên này không tồn tại",
    "This user is already a member of the circle" : "Người dùng này đã là thành viên của vòng kết nối",
    "Federated link not found" : "Liên kết Liên Bang không thể được tìm thấy",
    "This feature is not available for personal circles" : "Tính năng này không khả dụng cho các vòng kết nối cá nhân",
    "The circle is not federated" : "Vòng kết nối không được chia sẻ liên bang",
    "You cannot join this circle" : "Bạn không thể tham gia vòng kết nối này",
    "This member is not a moderator" : "Thành viên này không phải là người điều hành",
    "Insufficient privileges" : "Không đủ các quyền hạn",
    "This member is the owner of the circle" : "Thành viên này là chủ nhân của vòng kết nối",
    "Level cannot be changed for this type of member" : "Cấp độ không thể được thay đổi cho kiểu loại của thành viên này",
    "You are already a member of this circle" : "Bạn đã là thành viên của vòng kết nối này",
    "You have been blocked from this circle" : "Bạn đã bị chặn khỏi vòng kết nối này",
    "The user is already a member of this circle" : "Người dùng này đã là thành viên của vòng kết nối này",
    "The user has already been invited into this circle" : "Người dùng này đã được mời vào vòng kết nối này",
    "You are now a member of the Circle \"%2$s\"" : "Bây giờ bạn là thành viên của Vòng kết nối \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Bạn vừa mới được mời bởi %1$s vào Vòng kết nối \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s đã gửi một yêu cầu để là một thành viên của Vòng kết nối \"%2$s\"",
    "Accept" : "Đồng ý",
    "Refuse" : "Từ chối",
    "Leave the circle" : "Rời bỏ vòng kết nối",
    "Personal Circle" : "Vòng cá nhân",
    "You need a specify a type of circle" : "Bạn cần xác định một kiểu loại của vòng kết nối",
    "This member is not the owner of the circle" : "Thành viên này không phải là chủ nhân của vòng kết nối",
    "This member is not an admin of the circle" : "Thành viên này không phải là một quản trị viên của vòng kết nối này",
    "Group contains too many members" : "Nhóm chứa quá nhiều thành viên",
    "This group does not exist" : "Nhóm này không tồn tại",
    "This group is already linked to the circle" : "Nhóm này đã được liên kết tới vòng kết nối",
    "You cannot edit level in a personal circle" : "Bạn không thể sửa đổi mức độ trong một vòng kết nối cá nhân",
    "Group cannot be set as owner of a circle" : "Nhóm không thể được đặt với tư cách là chủ nhận của một vòng kết nối",
    "now" : "bây giờ",
    "This user does not exist" : "Người dùng này không tòn tại",
    "Email format is not valid" : "Định dạng thư điện tử không hợp lệ",
    "This contact is not available" : "Liên hệ này không khả dụng",
    "Could not find share" : "Không thể tìm thấy chia sẻ",
    "Bring cloud-users closer together." : "Mang các người dùng-điện toán đám mây đến gần nhau hơn",
    "No files in here" : "Không có tệp ở đây",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Name" : "Tên",
    "Size" : "Kích cỡ",
    "Modified" : "Thay đổi"
},
"nplurals=1; plural=0;");

==> nextcloud-23.0.12p0.tgz: nextcloud/apps/circles/l10n/vi.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Vòng kết nối",
    "Circles' files" : "Các tệp tin của các vòng kết nối",
    "Select circles to filter by" : "Chọn các vòng kết nối để lọc bởi",
    "No circles found" : "Không có vòng kết nối được tìm thấy",
    "Please select circles to filter by" : "Vui lòng chọn các vòng kết nới để lọc bởi",
    "No files found for the selected circles" : "Không có tệp được tìm thấy cho vòng kết nối được chọn",
    "You created the circle {circle}" : "Bạn đã tạo một vòng kết nối {circle}",
    "{author} created the circle {circle}" : "{author} đã tạo một vòng kết nối {circle}",
    "You deleted {circle}" : "Bạn đã xóa {circle}",
    "{author} deleted {circle}" : "{author} đã xóa {circle}",
    "You linked {group} to {circle}" : "Bạn đã liên kết {group} đến {circle}",
    "{group} has been linked to {circle} by {author}" : "{group} vừa mới được liên kết đến {circle } bởi {author}",
    "You unlinked {group} from {circle}" : " Bạn đã hủy liên kết {group} từ {circle}",
    "{group} has been unlinked from {circle} by {author}" : "{group} vừa mới được hủy liên kết từ {circle} bởi {author}",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "Bạn đã thay đổi cấp độ của nhóm được liên kết {group} trong {circle} ở mức %1$s",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} đã thay đổi cấp độ của nhóm được liên kết {group} trong {circle} ở mức %1$s",
    "You sent a request to link {circle} with {remote}" : "Bạn đã gửi 1 yêu cầu để liên kết {circle} với {remote}",
    "{author} sent a request to link {circle} with {remote}" : "{author} gửi một yêu cầu để liên kết {circle} với {remote}",
    "{remote} requested a link with {circle}" : "{remote} đã yêu cầu một liên kết với {circle}",
    "The request to link {circle} with {remote} has been rejected" : "Các yêu cầu để liên kết {circle} với {remote} đã bị từ chối",
    "The request to link {remote} with {circle} has been canceled remotely" : "Yêu cầu để liên kết {remote} với {circle} đã bị hủy bỏ từ xa",
    "The request to link {circle} with {remote} has been accepted" : "Yêu cầu để liên kết {circle} với {remote} đã được chấp thuận",
    "You dismissed the request to link {remote} with {circle}" : "Bạn đã bỏ qua yêu cầu liên kết {remote} với {circle}",
    "{author} dismissed the request to link {remote} with {circle}" : "{author} đã bỏ qua yêu cầu liên kết {remote} với {circle}",
    "You canceled the request to link {circle} with {remote}" : "Bạn đã hủy yêu cầu liên kết {circle} với {remote}",
    "{author} canceled the request to link {circle} with {remote}" : "{author} đã hủy yêu cầu liên kết {circle} với {remote}",
    "You accepted the request to link {remote} with {circle}" : "Bạn đã chấp thuận yêu cầu liên kết {remote} với {circle}",
    "{author} accepted the request to link {remote} with {circle}" : "{author} đã chấp thuận yêu cầu liên kết {remote} với {circle}",
    "A link between {circle} and {remote} is now up and running" : "Một liên kết giữa {circle} và {remote} bây giờ đã khả dụng và đang chạy",
    "The link between {circle} and {remote} has been shutdown remotely" : "Một liên kết giữa {circle} và {remote} đã được tắt từ xa",
    "You closed the link between {circle} and {remote}" : "Bạn đã đóng liên kết giữ {circle} và {remote}",
    "{author} closed the link between {circle} and {remote}" : "{author} đã đóng liên kết giữa {circle} và {remote}",
    "You joined {circle}" : "Bạn đã gia nhập {circle}",
    "{member} joined {circle}" : "{nember} đã gia nhập {circle}",
    "You accepted the invitation to join {circle}" : "Bạn đã chấp thuận lời mời để gia nhập {circle}",
    "{member} accepted the invitation to join {circle}" : "{member} đã chấp thuận lời mời để gia nhập {circle}",
    "You added {member} as member to {circle}" : "Bạn đã thêm {member} với tư cách là thành viên của {circle}",
    "You have been added as member to {circle} by {author}" : "Bạn đã được thêm vào nhóm {circle} với tư cách là thành viên bởi {author}",
    "{member} has been added as member to {circle} by {author}" : "{member} đã được thêm với tư cách là thành viên vào {circle} bởi {author}",
    "You added {external} to {circle}" : "Bạn đã thêm {external} vào {circle}",
    "{external} has been added to {circle} by {author}" : "{externa} vừa mới được thêm vào {circle} bởi {author}",
    "You accepted {member}'s request to join {circle}" : "Bạn đã chấp thuận yêu cầu liên kết của {member} để gia nhập {circle}",
    "Your request to join {circle} has been accepted by {author}" : "Yêu cầu gia nhập {circle} của bạn đã được chấp thuận bởi {author}",
    "{member}'s request to join {circle} has been accepted by {author}" : "Yêu cầu gia nhập của {member} vào {circle} vừa mới được chấp thuận bởi {author}",
    "You left {circle}" : "Bạn đã rời bỏ {circle}",
    "{member} left {circle}" : "{member} đã rời bỏ {circle}",
    "You declined the invitation to join {circle}" : "Bạn đã từ chối lời mời gia nhập vào {circle}",
    "{member} declined an invitation to join {circle}" : "{member} đã từ chối một lời mời gia nhập vào {circle}",
    "You cancelled your request to join {circle}" : "Bạn đã hủy bỏ yêu cầu của bạn để gia nhập {circle}",
    "{member} cancelled his request to join {circle}" : "{member} đã hủy bỏ yêu cầu của anh/chị ấy để gia nhập vào {circle}",
    "You removed {member} from {circle}" : "Bạn đã gỡ bỏ {member} ra khỏi {circle}",
    "You have been removed from {circle} by {author}" : "Bạn vừa mới bị gỡ bỏ khỏi {circle} bởi {author}",
    "{member} has been removed from {circle} by {author}" : "{member} vừa mới bị gỡ bỏ khỏi {circle} bởi {author}",
    "You removed {external} from {circle}" : "Bạn gỡ bỏ {external} khỏi {circle}",
    "{external} has been removed from {circle} by {author}" : "{external} vừa mới được gỡ bỏ khỏi {circle} bởi {author}",
    "You cancelled {member}'s invitation to join {circle}" : "Bạn đã hủy lời mời gia nhập vào {circle} của thành viên {member}",
    "Your invitation to join {circle} has been cancelled by {author}" : "Lời mời gia nhập vào {circle} của bạn đã bị hủy bỏ bởi {author}",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} đã hủy bỏ lời mời tham gia vào nhóm {circle} của {member} ",
    "You dismissed {member}'s request to join {circle}" : "Bạn đã bỏ qua yêu cầu gia nhập vào {circle} của {member}",
    "Your request to join {circle} has been dismissed by {author}" : "Yêu cầu gia nhập vào {circle} của bạn đã bị bỏ qua bởi {author}",
    "{member}'s request to join {circle} has been dismissed by {author}" : "Yêu cầu gia nhập vào {circle} của {member} đã bị bỏ qua bởi {author}",
    "You invited {member} to join {circle}" : "Bạn đã mời {member} để gia nhập vào {circle}",
    "You have been invited to join {circle} by {author}" : "Bạn vừa mới được mời để gia nhập vào {circle} bởi {author}",
    "{member} has been invited to join {circle} by {author}" : "{member} vừa mới được mời để gia nhập vào {circle} bởi {author}",
    "You changed {member}'s level in {circle} to %1$s" : "Bạn đã thay đổi cấp độ của {member} trong {circle} ở mức %1$s",
    "{author} changed your level in {circle} to %1$s" : "{author} đã thay đổi cấp độ của bạn trong {circle} ở mức %1$s",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} đã thay đổi cấp độ của {member} trong {circle} ở mức %1$s",
    "You sent a request to join {circle}" : "Bạn đã gửi một yêu cầu để gia nhập {circle}",
    "{member} sent a request to join {circle}" : "{member} đã gửi một yêu cầu để gia nhập {circle}",
    "You are the new owner of {circle}" : "Bạn là chủ nhân mới của {circle}",
    "{member} is the new owner of {circle}" : "{member} là chủ nhân mới của {circle}",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "Trên những sự kiên đang diễn ra trong một <strong> Vòng kết nối </strong> mà bạn là thành viên của nhóm",
    "Any important event in a <strong>Circle</strong> you are moderating" : "Một sự kiện quan trọng trong một <strong> Vòng kết nối </strong> mà bạn đang điều hành",
    "On global events happening in any <strong>Circle</strong>" : "Trên những sự kiện chung đang diễn ra của tổ chức trong bất cứ <strong> Vòng kết nối </strong>",
    "Personal" : "Cá nhân",
    "Open" : "Mở",
    "Hidden" : "Ẩn",
    "Federated" : "Federated",
    "Contact" : "Liên hệ",
    "Circle" : "Vòng kết nối",
    "Member" : "Thành viên",
    "Moderator" : "Kiểm duyệt",
    "Admin" : "Quản trị",
    "Owner" : "Chủ",
    "%s shared »%s« with you." : "%s đã chia sẻ »%s« với bạn",
    "%s on %s" : "%s trên %s",
    "Password to access »%1$s« shared to you by %2$s" : "Mật khẩu để truy cập »%1$s« đã được chia sẻ tới bạn bởi %2$s",
    "Password to access »%s«" : "Mật khẩu để truy cập »%s«",
    "It is protected with the following password:" : "Nó được bảo vệ bởi mật khẩu sau đây:",
    "%1$s via %2$s" : "%1$s thông qua %2$s",
    "Click the button below to open it." : "Bấm vào nút bên dưới để mở nó.",
    "Open »%s«" : "Mở »%s«",
    "Password to access files shared to you by %1$s" : "Mật khẩu để truy cập vào các tệp đã được chia sẻ tới bạn bởi %1$s",
    "Password to access files" : "Mật khẩu để truy cập các tệp",
    "%s shared multiple files with you." : "%s đã chia sẻ tổ hợp tệp với bạn.",
    "Circle not found" : "Vòng kết nối không được tìm thấy",
    "Circle not found " : "Vòng kết nối không được tìm thấy",
    "This member does not exist" : "Thành viên này không tồn tại",
    "Federated link not found" : "Liên kết Liên Bang không thể được tìm thấy",
    "This feature is not available for personal circles" : "Tính năng này không khả dụng cho các vòng kết nối cá nhân",
    "The circle is not federated" : "Vòng kết nối không được chia sẻ liên bang",
    "You cannot join this circle" : "Bạn không thể tham gia vòng kết nối này",
    "This member is not a moderator" : "Thành viên này không phải là người điều hành",
    "Insufficient privileges" : "Không đủ các quyền hạn",
    "This member is the owner of the circle" : "Thành viên này là chủ nhân của vòng kết nối",
    "Level cannot be changed for this type of member" : "Cấp độ không thể được thay đổi cho kiểu loại của thành viên này",
    "You are already a member of this circle" : "Bạn đã là thành viên của vòng kết nối này",
    "You have been blocked from this circle" : "Bạn đã bị chặn khỏi vòng kết nối này",
    "You are now a member of the Circle \"%2$s\"" : "Bây giờ bạn là thành viên của Vòng kết nối \"%2$s\"",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "Bạn vừa mới được mời bởi %1$s vào Vòng kết nối \"%2$s\"",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$s đã gửi một yêu cầu để là một thành viên của Vòng kết nối \"%2$s\"",
    "Accept" : "Đồng ý",
    "Refuse" : "Từ chối",
    "Leave the circle" : "Rời bỏ vòng kết nối",
    "Personal Circle" : "Vòng cá nhân",
    "You need a specify a type of circle" : "Bạn cần xác định một kiểu loại của vòng kết nối",
    "A circle with that name exists" : "Đã tồn tại một vòng kết nối có tên đó",
    "This member is not the owner of the circle" : "Thành viên này không phải là chủ nhân của vòng kết nối",
    "This member is not an admin of the circle" : "Thành viên này không phải là một quản trị viên của vòng kết nối này",
    "Group contains too many members" : "Nhóm chứa quá nhiều thành viên",
    "This group does not exist" : "Nhóm này không tồn tại",
    "This group is already linked to the circle" : "Nhóm này đã được liên kết tới vòng kết nối",
    "You cannot edit level in a personal circle" : "Bạn không thể sửa đổi mức độ trong một vòng kết nối cá nhân",
    "Group cannot be set as owner of a circle" : "Nhóm không thể được đặt với tư cách là chủ nhận của một vòng kết nối",
    "now" : "bây giờ",
    "Email format is not valid" : "Định dạng thư điện tử không hợp lệ",
    "This contact is not available" : "Liên hệ này không khả dụng",
    "Bring cloud-users closer together." : "Mang các người dùng-điện toán đám mây đến gần nhau hơn",
    "No files in here" : "Không có tệp ở đây",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Name" : "Tên",
    "Size" : "Kích cỡ",
    "Modified" : "Thay đổi",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Bạn không thể sử dụng Ứng dụng Vòng kết nối cho đến khi quản trị viên của bạn cho phép ít nhất một loại của vòng kết nối",
    "This user is already a member of the circle" : "Người dùng này đã là thành viên của vòng kết nối",
    "The user is already a member of this circle" : "Người dùng này đã là thành viên của vòng kết nối này",
    "The user has already been invited into this circle" : "Người dùng này đã được mời vào vòng kết nối này",
    "This user does not exist" : "Người dùng này không tòn tại",
    "Could not find share" : "Không thể tìm thấy chia sẻ"
},
"nplurals=1; plural=0;");
